==> eiffelstudio-18.11.10.2592.tar: F_code/C26/xm1261.c <==
/*
 * Code for class XM_XSLT_COMMENT
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "xm1261.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {XM_XSLT_COMMENT}.select_and_content_error */
EIF_REFERENCE F2133_21823 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(1);
	RTLR(0,Result);
	RTLIU(1);
	
	RTGC;
	Result = RTMS_EX_H("XTSE0940",8,322033200);
	RTLE;
	return Result;
}

/* {XM_XSLT_COMMENT}.prepare_attributes */
void F2133_21824 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_INTEGER_32 loc2 = (EIF_INTEGER_32) 0;
	EIF_REFERENCE loc3 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc4 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc5 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc6 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc7 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	RTLD;
	
	RTLI(9);
	RTLR(0,loc5);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLR(3,loc1);
	RTLR(4,loc3);
	RTLR(5,tr2);
	RTLR(6,loc4);
	RTLR(7,loc6);
	RTLR(8,loc7);
	RTLIU(9);
	
	RTGC;
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_6_);
	loc5 = tr1;
	if (EIF_TEST(loc5)) {
		loc1 = F1201_9938(loc5);
		F1278_11088(RTCW(loc1));
		for (;;) {
			tb1 = '\01';
			tb2 = F1333_11163(RTCW(loc1));
			if (!tb2) {
				tb1 = F2078_21082(Current);
			}
			if (tb1) break;
			loc2 = F1268_11068(RTCW(loc1));
			tr1 = RTOSCF(4804,F948_4804,(Current));
			loc3 = F1212_10253(RTCW(tr1), loc2);
			tr1 = RTOSCF(8261,F1130_8261,(Current));
			tr2 = RTOSCF(2456,F314_2456,(Current));
			tb2 = F1115_8100(RTCW(tr1), loc3, tr2);
			if (tb2) {
				ti4_1 = F1329_11143(RTCW(loc1));
				loc4 = F2066_20824(Current, ti4_1);
				tr1 = RTOSCF(8261,F1130_8261,(Current));
				F1115_8116(RTCW(tr1), loc4);
				tr1 = RTOSCF(8261,F1130_8261,(Current));
				F1115_8117(RTCW(tr1), loc4);
			} else {
				F2078_21135(Current, loc2);
			}
			F1278_11089(RTCW(loc1));
		}
	}
	if ((EIF_BOOLEAN)(loc4 != NULL)) {
		F2078_21148(Current, loc4);
		RTCT0("postcondition_of_generate_expression", EX_CHECK);
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_17_);
		loc6 = tr1;
		if (EIF_TEST(loc6)) {
			RTCK0;
		} else {
			RTCF0;
		}
		RTAR(Current, loc6);
		*(EIF_REFERENCE *)(Current + _REFACS_24_) = (EIF_REFERENCE) loc6;
		tr1 = *(EIF_REFERENCE *)(loc6 + O13531[Dtype(loc6)-1792]);
		loc7 = tr1;
		if (EIF_TEST(loc7)) {
			F2078_21132(Current, loc7);
		}
	}
	*(EIF_BOOLEAN *)(Current+ _CHROFF_25_2_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
	RTLE;
}

/* {XM_XSLT_COMMENT}.validate */
void F2133_21825 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(4);
	RTLR(0,loc2);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLR(3,loc1);
	RTLIU(4);
	
	RTGC;
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_24_);
	loc2 = tr1;
	if (EIF_TEST(loc2)) {
		{
			static EIF_TYPE_INDEX typarr0[] = {193,1792,0xFFFF};
			EIF_TYPE typres0;
			static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
			
			typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
			tr1 = RTLNS(typres0.id, 193, _OBJSIZ_1_0_0_0_0_0_0_0_);
		}
		F194_1706(RTCW(tr1), NULL);
		loc1 = (EIF_REFERENCE) tr1;
		tr1 = RTMS_EX_H("select",6,2045458804);
		F2078_21140(Current, loc1, tr1, loc2);
		tr1 = *(EIF_REFERENCE *)(RTCW(loc1));
		RTAR(Current, tr1);
		*(EIF_REFERENCE *)(Current + _REFACS_24_) = (EIF_REFERENCE) tr1;
	}
	F2078_21142(Current);
	F2128_21796(Current);
	*(EIF_BOOLEAN *)(Current+ _CHROFF_25_3_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
	RTLE;
}

/* {XM_XSLT_COMMENT}.compile */
void F2133_21826 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	RTLD;
	
	RTLI(6);
	RTLR(0,loc1);
	RTLR(1,tr1);
	RTLR(2,arg1);
	RTLR(3,loc2);
	RTLR(4,tr2);
	RTLR(5,Current);
	RTLIU(6);
	
	RTGC;
	tr1 = RTLNS(eif_new_type(2049, 0x00).id, 2049, _OBJSIZ_10_38_0_3_0_0_0_0_);
	F2050_20568(RTCW(tr1), arg1);
	loc1 = (EIF_REFERENCE) tr1;
	tr1 = RTLNS(eif_new_type(1808, 0x00).id, 1808, _OBJSIZ_10_38_0_1_0_0_0_0_);
	tr2 = RTMS_EX_H(" ",1,32);
	F1809_17928(RTCW(tr1), tr2);
	loc2 = (EIF_REFERENCE) tr1;
	F2128_21797(Current, arg1, loc1, loc2);
	RTAR(Current, loc1);
	*(EIF_REFERENCE *)(Current + _REFACS_17_) = (EIF_REFERENCE) loc1;
	RTLE;
}

void EIF_Minit1261 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-19.05.10.3187.tar: F_code/C26/xm1261.c <==
/*
 * Code for class XM_XSLT_COMMENT
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "xm1261.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {XM_XSLT_COMMENT}.select_and_content_error */
EIF_REFERENCE F2139_21864 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(1);
	RTLR(0,Result);
	RTLIU(1);
	
	RTGC;
	Result = RTMS_EX_H("XTSE0940",8,322033200);
	RTLE;
	return Result;
}

/* {XM_XSLT_COMMENT}.prepare_attributes */
void F2139_21865 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_INTEGER_32 loc2 = (EIF_INTEGER_32) 0;
	EIF_REFERENCE loc3 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc4 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc5 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc6 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc7 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	RTLD;
	
	RTLI(9);
	RTLR(0,loc5);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLR(3,loc1);
	RTLR(4,loc3);
	RTLR(5,tr2);
	RTLR(6,loc4);
	RTLR(7,loc6);
	RTLR(8,loc7);
	RTLIU(9);
	
	RTGC;
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_6_);
	loc5 = tr1;
	if (EIF_TEST(loc5)) {
		loc1 = F1201_9969(loc5);
		F1284_11121(RTCW(loc1));
		for (;;) {
			tb1 = '\01';
			tb2 = F1338_11196(RTCW(loc1));
			if (!tb2) {
				tb1 = F2085_21129(Current);
			}
			if (tb1) break;
			loc2 = F1274_11101(RTCW(loc1));
			tr1 = RTOSCF(4820,F948_4820, (Current));
			loc3 = F1212_10284(RTCW(tr1), loc2);
			tr1 = RTOSCF(8292,F1130_8292, (Current));
			tr2 = RTOSCF(2428,F310_2428, (Current));
			tb2 = F1115_8131(RTCW(tr1), loc3, tr2);
			if (tb2) {
				ti4_1 = F1335_11176(RTCW(loc1));
				loc4 = F2073_20871(Current, ti4_1);
				tr1 = RTOSCF(8292,F1130_8292, (Current));
				F1115_8147(RTCW(tr1), loc4);
				tr1 = RTOSCF(8292,F1130_8292, (Current));
				F1115_8148(RTCW(tr1), loc4);
			} else {
				F2085_21182(Current, loc2);
			}
			F1284_11122(RTCW(loc1));
		}
	}
	if ((EIF_BOOLEAN)(loc4 != NULL)) {
		F2085_21195(Current, loc4);
		RTCT0("postcondition_of_generate_expression", EX_CHECK);
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_17_);
		loc6 = tr1;
		if (EIF_TEST(loc6)) {
			RTCK0;
		} else {
			RTCF0;
		}
		RTAR(Current, loc6);
		*(EIF_REFERENCE *)(Current + _REFACS_24_) = (EIF_REFERENCE) loc6;
		tr1 = *(EIF_REFERENCE *)(loc6 + O13562[Dtype(loc6)-1799]);
		loc7 = tr1;
		if (EIF_TEST(loc7)) {
			F2085_21179(Current, loc7);
		}
	}
	*(EIF_BOOLEAN *)(Current+ _CHROFF_25_2_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
	RTLE;
}

/* {XM_XSLT_COMMENT}.validate */
void F2139_21866 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(4);
	RTLR(0,loc2);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLR(3,loc1);
	RTLIU(4);
	
	RTGC;
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_24_);
	loc2 = tr1;
	if (EIF_TEST(loc2)) {
		{
			static EIF_TYPE_INDEX typarr0[] = {0xFF01,195,1799,0xFFFF};
			EIF_TYPE typres0;
			static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
			
			typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
			loc1 = RTLNS(typres0.id, 195, _OBJSIZ_1_0_0_0_0_0_0_0_);
		}
		F196_1714(RTCW(loc1), NULL);
		tr1 = RTMS_EX_H("select",6,2045458804);
		F2085_21187(Current, loc1, tr1, loc2);
		tr1 = *(EIF_REFERENCE *)(RTCW(loc1));
		RTAR(Current, tr1);
		*(EIF_REFERENCE *)(Current + _REFACS_24_) = (EIF_REFERENCE) tr1;
	}
	F2085_21189(Current);
	F2135_21843(Current);
	*(EIF_BOOLEAN *)(Current+ _CHROFF_25_3_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
	RTLE;
}

/* {XM_XSLT_COMMENT}.compile */
void F2139_21867 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(5);
	RTLR(0,loc1);
	RTLR(1,arg1);
	RTLR(2,loc2);
	RTLR(3,tr1);
	RTLR(4,Current);
	RTLIU(5);
	
	RTGC;
	loc1 = RTLNS(eif_new_type(2055, 0x01).id, 2055, _OBJSIZ_10_38_0_3_0_0_0_0_);
	F2056_20599(RTCW(loc1), arg1);
	loc2 = RTLNS(eif_new_type(1815, 0x01).id, 1815, _OBJSIZ_10_38_0_1_0_0_0_0_);
	tr1 = RTMS_EX_H(" ",1,32);
	F1816_17975(RTCW(loc2), tr1);
	F2135_21844(Current, arg1, loc1, loc2);
	RTAR(Current, loc1);
	*(EIF_REFERENCE *)(Current + _REFACS_17_) = (EIF_REFERENCE) loc1;
	RTLE;
}

void EIF_Minit1261 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
